@@ -28,6 +28,7 @@
 
 #include <gtk/gtkmessagedialog.h>
 #include <gtk/gtkhbox.h>
+#include <gtk/gtkicontheme.h>
 #include <libgnomeui/libgnomeui.h>
 
 #include <bonobo/bonobo-shlib-factory.h>
@@ -52,6 +53,7 @@ typedef struct
   PanelApplet *applet;
 
   GtkWidget *box;
+  GtkWidget *about_dialog;
   GtkWidget *frame;
 
   GtkOrientation orientation;
@@ -67,7 +69,7 @@ help_cb (PanelApplet *applet,
 
   err = NULL;  
   gnome_help_display_desktop_on_screen (NULL, "user-guide",
-                                        "wgospanel.xml", "gospanel-567",
+                                        "user-guide.xml", "gospanel-567",
 					gtk_widget_get_screen (GTK_WIDGET (applet)),
 					&err);
 
@@ -98,12 +100,13 @@ help_cb (PanelApplet *applet,
 
 
 static void
-about_cb (PanelApplet *applet,
-          void        *data)
+about_cb (BonoboUIComponent *uic,
+          SystemTray        *tray,
+          const gchar       *verbname)
 {
-  static GtkWidget *about = NULL;
-  GdkPixbuf *pixbuf = NULL;
-  gchar *file;
+  GdkPixbuf    *pixbuf;
+  GtkIconTheme *icon_theme;
+  GdkScreen    *screen;
 
   const char *authors[] = {
     "Havoc Pennington <hp@redhat.com>",
@@ -111,33 +114,44 @@ about_cb (PanelApplet *applet,
     NULL
   };
   const char *documenters [] = {
+    "Sun GNOME Documentation Team <gdocteam@sun.com>",
     NULL
   };
   const char *translator_credits = _("translator_credits");
 
-  if (about)
+  screen = gtk_widget_get_screen (GTK_WIDGET (tray->applet));
+
+  if (tray->about_dialog)
     {
-      gtk_window_present (GTK_WINDOW (about));
+      gtk_window_set_screen (GTK_WINDOW (tray->about_dialog), screen);
+      gtk_window_present (GTK_WINDOW (tray->about_dialog));
       return;
     }
 
-  file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "notification-area-applet.png",
-                                    TRUE, NULL);
-  pixbuf = gdk_pixbuf_new_from_file (file, NULL);
-  g_free (file);
+  icon_theme = gtk_icon_theme_get_for_screen (screen);
+  pixbuf = gtk_icon_theme_load_icon (icon_theme,
+				     "panel-notification-area",
+                                     48,
+				     0,
+				     NULL);
 
-  about = gnome_about_new (_("Panel Notification Area"), VERSION,
-                           "Copyright \xc2\xa9 2002 Red Hat, Inc.",
-                           NULL,
-                           (const char **)authors,
-                           (const char **)documenters,
-                           strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-                           pixbuf);
+  tray->about_dialog = gnome_about_new (_("Panel Notification Area"), VERSION,
+					"Copyright \xc2\xa9 2002 Red Hat, Inc.",
+					NULL,
+					(const char **) authors,
+					(const char **) documenters,
+					strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+					pixbuf);
   
-  g_object_add_weak_pointer (G_OBJECT (about),
-                             (gpointer) &about);
+  if (pixbuf)
+    g_object_unref (pixbuf);
 
-  gtk_widget_show (about);
+  gtk_window_set_screen (GTK_WINDOW (tray->about_dialog), screen);
+
+  g_object_add_weak_pointer (G_OBJECT (tray->about_dialog),
+                             (gpointer) &tray->about_dialog);
+
+  gtk_widget_show (tray->about_dialog);
 }
 
 static const BonoboUIVerb menu_verbs [] = {
@@ -278,6 +292,14 @@ applet_change_pixel_size (PanelApplet  *applet,
   update_size_and_orientation (tray);
 }
 
+static void
+applet_destroy (PanelApplet *applet,
+		SystemTray  *tray)
+{
+  if (tray->about_dialog)
+    gtk_widget_destroy (tray->about_dialog);
+}
+
 static void
 free_tray (SystemTray *tray)
 {
@@ -379,6 +401,11 @@ applet_factory (PanelApplet *applet,
                     G_CALLBACK (applet_change_background),
                     tray);
 
+  g_signal_connect (tray->applet,
+                    "destroy",
+                    G_CALLBACK (applet_destroy),
+                    tray);
+
   update_size_and_orientation (tray);
   
   gtk_container_add (GTK_CONTAINER (tray->applet), tray->frame);
