@@ -93,7 +93,7 @@ key_press_drawer (GtkWidget   *widget,
 	gboolean retval = TRUE;
 	GtkOrientation orient;
 
-	if (event->state == gtk_accelerator_get_default_mod_mask ())
+	if (event->state & gtk_accelerator_get_default_mod_mask ())
 		return FALSE;
 
 	orient = PANEL_WIDGET (drawer->button->parent)->orient;
@@ -169,7 +169,7 @@ key_press_drawer_widget (GtkWidget   *widget,
 
 	gtk_window_present (GTK_WINDOW (panel_widget->toplevel));
 
-	if (event->state == GDK_SHIFT_MASK ||
+	if ((event->state & gtk_accelerator_get_default_mod_mask ()) == GDK_SHIFT_MASK ||
 	    panel_toplevel_get_is_hidden (drawer->toplevel))
 		return TRUE;
 
@@ -536,6 +536,12 @@ panel_drawer_connect_to_gconf (Drawer *drawer)
 	g_assert (i == PANEL_DRAWER_N_LISTENERS);
 }
 
+static gboolean
+drawer_properties_enabled (void)
+{
+  return !panel_lockdown_get_locked_down ();
+}
+
 static void
 load_drawer_applet (char          *toplevel_id,
 		    const char    *custom_icon,
@@ -597,7 +603,7 @@ load_drawer_applet (char          *toplevel_id,
 				   "properties",
 				   GTK_STOCK_PROPERTIES,
 				   _("_Properties"),
-				   panel_lockdown_get_locked_down);
+				   drawer_properties_enabled);
 
 	panel_applet_add_callback (drawer->info,
 				   "help",
